CellOracle
==========

|GitHub Workflow Status| |PyPI| |PyPI - Python Version| |PyPI - Wheel|
|Downloads| |Docker Pulls|

CellOracle is a python library for in silico gene perturbation analyses
using single-cell omics data and Gene Regulatory Network models.

For more information, please read our paper: `Dissecting cell identity
via network inference and in silico gene
perturbation <https://www.nature.com/articles/s41586-022-05688-9>`__.

Documentation, Codes, and Tutorials
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

CellOracle documentation is available through the link below.

`Web
documentation <https://morris-lab.github.io/CellOracle.documentation/>`__

Questions and errors
~~~~~~~~~~~~~~~~~~~~

If you have a question, error, bug, or problem, please use the `Github
issue page <https://github.com/morris-lab/CellOracle/issues>`__.

Supported Species and reference genomes
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

-  Human: [‘hg38’, ‘hg19’]
-  Mouse: [‘mm39’, ‘mm10’, ‘mm9’]
-  S.cerevisiae: [“sacCer2”, “sacCer3”]
-  Zebrafish: [“danRer7”, “danRer10”, “danRer11”]
-  Xenopus tropicalis: [“xenTro2”, “xenTro3”]
-  Xenopus laevis: [“Xenopus_laevis_v10.1”]
-  Rat: [“rn4”, “rn5”, “rn6”]
-  Drosophila: [“dm3”, “dm6”]
-  C.elegans: [“ce6”, “ce10”]
-  Arabidopsis: [“TAIR10”]
-  Chicken: [“galGal4”, “galGal5”, “galGal6”]
-  Guinea Pig: [“Cavpor3.0”]
-  Pig: [“Sscrofa11.1”]

Changelog
~~~~~~~~~

Please go to `this
page <https://morris-lab.github.io/CellOracle.documentation/changelog/index.html>`__.

.. |GitHub Workflow Status| image:: https://img.shields.io/github/actions/workflow/status/morris-lab/CellOracle/build_check.yml?branch=master
   :target: https://github.com/morris-lab/CellOracle/actions/workflows/build_check.yml
.. |PyPI| image:: https://img.shields.io/pypi/v/celloracle?color=blue
   :target: https://pypi.org/project/celloracle/
.. |PyPI - Python Version| image:: https://img.shields.io/pypi/pyversions/celloracle
   :target: https://pypi.org/project/celloracle/
.. |PyPI - Wheel| image:: https://img.shields.io/pypi/wheel/celloracle
   :target: https://pypi.org/project/celloracle/
.. |Downloads| image:: https://static.pepy.tech/personalized-badge/celloracle?period=total&units=international_system&left_color=grey&right_color=orange&left_text=Downloads
   :target: https://pepy.tech/project/celloracle
.. |Docker Pulls| image:: https://img.shields.io/docker/pulls/kenjikamimoto126/celloracle_ubuntu?color=red
   :target: https://hub.docker.com/r/kenjikamimoto126/celloracle_ubuntu
